#Anil
It takes an integer as an input and prints it square.

##Installation
```pip install hello```

##How to use it?
Open terminal and type square and then input the integer

##License
© 2021 K L Ani 

This repository is licensed under the MIT license. See LICENSE for details.